summaryrefslogtreecommitdiffstats
path: root/crypto/init.c
diff options
context:
space:
mode:
authorMatt Caswell <matt@openssl.org>2016-04-04 17:00:04 +0100
committerMatt Caswell <matt@openssl.org>2016-04-13 08:52:33 +0100
commitcbf6959fe8ff51730a397ea426075d547ec5d7a8 (patch)
treeeef161225ca88ad3d6471c81c942dc6c7f3a26df /crypto/init.c
parent6d4fb1d59e61aacefa25edc4fe5acfe1ac93f743 (diff)
Deprecate CONF_modules_free() and make it a no-op
CONF_modules_free() should not be called expicitly - we should leave auto-deinit to clean this up instead. Reviewed-by: Tim Hudson <tjh@openssl.org> Reviewed-by: Richard Levitte <levitte@openssl.org>
Diffstat (limited to 'crypto/init.c')
-rw-r--r--crypto/init.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/crypto/init.c b/crypto/init.c
index ca19408bef..f5473ecfe3 100644
--- a/crypto/init.c
+++ b/crypto/init.c
@@ -457,7 +457,7 @@ void OPENSSL_cleanup(void)
fprintf(stderr, "OPENSSL_INIT: OPENSSL_cleanup: "
"rand_cleanup_intern()\n");
fprintf(stderr, "OPENSSL_INIT: OPENSSL_cleanup: "
- "CONF_modules_free()\n");
+ "conf_modules_free_intern()\n");
#ifndef OPENSSL_NO_ENGINE
fprintf(stderr, "OPENSSL_INIT: OPENSSL_cleanup: "
"engine_cleanup_intern()\n");
@@ -477,11 +477,11 @@ void OPENSSL_cleanup(void)
* must be called before engine_cleanup_intern()
* - ENGINEs use CRYPTO_EX_DATA and therefore, must be cleaned up
* before the ex data handlers are wiped in CRYPTO_cleanup_all_ex_data().
* - CONF_modules_free() can end up in ENGINE code so must be called before
* engine_cleanup_intern()
*/
rand_cleanup_intern();
- CONF_modules_free();
+ conf_modules_free_intern();
#ifndef OPENSSL_NO_ENGINE
engine_cleanup_intern();
#endif
@@ -477,11 +477,11 @@ void OPENSSL_cleanup(void)
* - ENGINEs use CRYPTO_EX_DATA and therefore, must be cleaned up
* before the ex data handlers are wiped in CRYPTO_cleanup_all_ex_data().
- * - CONF_modules_free() can end up in ENGINE code so must be called before
- * engine_cleanup_intern()
+ * - conf_modules_free_intern() can end up in ENGINE code so must be called
+ * before engine_cleanup_intern()
*/
rand_cleanup_intern();